# CHANGES

## 0.4.3.1 (2025-08-02)

- Resolve mecabrc not found issue
- Support Python 3.12, 3.13
- Drop supporting Python 3.8
- Migrate packaging solution from setup.py to pyproject.toml

## 0.4.2 (2023-02-19)

- Enable user's dictionary
- Solve install issue
- Support Python 3.11
- PEP8

## 0.3.1 (2022-08-17)

- Improve dictionaries
- Use Bunkai module instead of sengiri

## 0.2 (2019-10-07)

- Add new methods count_polarity (thanks @yskn67) and analyze_detail
- Drop support Python 3.3
- Use sengiri package
- Support parallel negation (e.g. お金も希望もない is negative)
- Support "arujanai" expression (e.g. お金があるじゃない is positive)

## 0.1.2 (2019-02-18)

- Fix missing CHANGES.rst

## 0.1.1 (2019-02-13)

- Set install_requires

## 0.1 (2019-02-12)

- First release
